@@ -22,7 +22,7 @@ sub new($%) {
 
 sub TextFmt($$;$) {
     my($oThis, $sTxt, $sCode) =@_;
-    $sCode = 'sjis' if($sCode eq '_native_');
+    $sCode = 'sjis' if(defined($sCode) && ($sCode eq '_native_'));
 
     if($oThis->{Code}) {
         return Jcode::convert($sTxt, $oThis->{Code}, $sCode);
@@ -149,3 +149,4 @@ sub ChkType($$$) {
         return "Text";
     }
 }
+1;
